cycler: Composable cycles
=========================

Description
-----------

Cycler is a small break-off of matplotlib to deal with "composable
cycles". It is a required dependency of matplotlib 1.5.0.

License
-------

BSD


Upstream Contact
----------------

cycler is developed on github: https://github.com/matplotlib/cycler

A more informative webpage about cycler, its motivation and usage is at
http://tacaswell.github.io/cycler/

Dependencies
------------

-  python
-  setuptools
-  six
